@@ -31,7 +31,7 @@ class MsgfmtBuildHook(BuildHookInterface):
         print(f'{self.build_config.default_exclude()=}')
         print(f'{self.build_config.default_only_include()=}')
         print(f'{self.build_config.default_packages()=}')
-        print(f'{self.build_config.builder.recurse_included_files()=}')
+        print(f'{list(self.build_config.builder.recurse_included_files())=}')
 
     def finalize(self, version: str, build_data: dict[str, Any], artifact_path: str) -> None:
         if self.target_name != 'wheel':
@@ -46,7 +46,7 @@ class MsgfmtBuildHook(BuildHookInterface):
         print(f'{self.build_config.default_exclude()=}')
         print(f'{self.build_config.default_only_include()=}')
         print(f'{self.build_config.default_packages()=}')
-        print(f'{self.build_config.builder.recurse_included_files()=}')
+        print(f'{list(self.build_config.builder.recurse_included_files())=}')
 
 @hookimpl
 def hatch_register_build_hook():
